pub struct TilePrefetcher {
pub radius: u8,
pub max_zoom_delta: u8,
}Expand description
Pre-fetches neighboring tiles based on the current access pattern.
Fields
radius: u8How many tiles around the current tile to prefetch (Chebyshev radius).
max_zoom_delta: u8Prefetch this many zoom levels above and below the current zoom.
Implementations
Sourceimpl TilePrefetcher
impl TilePrefetcher
Sourcepub fn new(radius: u8) -> Self
pub fn new(radius: u8) -> Self
Creates a new TilePrefetcher with the given radius and a default
max_zoom_delta of 1.